@@ -221,9 +221,11 @@ impl<'a> BinNMU<'a> {
     pub fn new(source: &'a SourceSpecifier<'a>, message: &'a str) -> Result<Self, Error> {
         for arch in &source.architectures {
             match arch {
-                // unable to nmu with source, -source, ALL
+                // unable to nmu with source, -source, ALL, all
                 &WBArchitecture::Architecture(Architecture::Source)
                 | &WBArchitecture::MinusArchitecture(Architecture::Source)
+                | &WBArchitecture::Architecture(Architecture::All)
+                | &WBArchitecture::MinusArchitecture(Architecture::All)
                 | &WBArchitecture::All => {
                     return Err(Error::InvalidArchitecture(arch.clone(), "nmu"));
                 }
@@ -314,7 +316,7 @@ impl<'a> DepWait<'a> {
                 // unable to dw with source, -source
                 &WBArchitecture::Architecture(Architecture::Source)
                 | &WBArchitecture::MinusArchitecture(Architecture::Source) => {
-                    return Err(Error::InvalidArchitecture(arch.clone(), "nmu"));
+                    return Err(Error::InvalidArchitecture(arch.clone(), "dw"));
                 }
                 _ => {}
             }
@@ -345,7 +347,7 @@ impl<'a> BuildPriority<'a> {
                 // unable to bp with source, -source
                 &WBArchitecture::Architecture(Architecture::Source)
                 | &WBArchitecture::MinusArchitecture(Architecture::Source) => {
-                    return Err(Error::InvalidArchitecture(arch.clone(), "nmu"));
+                    return Err(Error::InvalidArchitecture(arch.clone(), "bp"));
                 }
                 _ => {}
             }
